searchData={"items":[{"type":"module","title":"TimeZoneInfo","doc":"`TimeZoneInfo` provides a time zone database for\n[Elixir](https://elixir-lang.org/) using the data from the\n[the Internet Assigned Numbers Authority (IANA)](https://www.iana.org/time-zones).\n\nTherefore `TimeZoneInfo` contains an implementation of the\n`Calendar.TimeZoneDatabase` behaviour under `TimeZoneInfo.TimeZoneDatabase`.","ref":"TimeZoneInfo.html"},{"type":"function","title":"TimeZoneInfo.data/2","doc":"Generates `TimeZoneInfo.data` from the given `iana_data_archive`.","ref":"TimeZoneInfo.html#data/2"},{"type":"function","title":"TimeZoneInfo.iana_version/0","doc":"Returns the version of the IANA database.","ref":"TimeZoneInfo.html#iana_version/0"},{"type":"function","title":"TimeZoneInfo.info/0","doc":"Returns infos about persisted and stored data.","ref":"TimeZoneInfo.html#info/0"},{"type":"function","title":"TimeZoneInfo.next_update/0","doc":"Returns the date time in UTC for the next update. Retruns `:never` if the\nautomated update disabled.","ref":"TimeZoneInfo.html#next_update/0"},{"type":"function","title":"TimeZoneInfo.state/0","doc":"Returns the state of `TimeZoneInfo`.\n\nReturns\n- `:ok` if everything runs normal and the automated update is disabled.\n- `{:next, seconds}` if everything runs normal.\n- `{:error, reason}` in case of an error.","ref":"TimeZoneInfo.html#state/0"},{"type":"function","title":"TimeZoneInfo.time_zones/1","doc":"Returns the list of all available time zones with or without links. The option\n`:links` can be used to customize the list.\n\nValues for `:links`:\n- `:ignore` just the time zone names will be returned\n- `:only` just the link names will be returned\n- `:include` the time zone and link names will be returned (default)\n\nThe list will be sorted.","ref":"TimeZoneInfo.html#time_zones/1"},{"type":"function","title":"TimeZoneInfo.update/1","doc":"Triggers the update process. Withe the `opt` `:force` the update will be\nforced.","ref":"TimeZoneInfo.html#update/1"},{"type":"type","title":"TimeZoneInfo.data/0","doc":"The data structure containing all informations for `TimeZoneInfo`.","ref":"TimeZoneInfo.html#t:data/0"},{"type":"type","title":"TimeZoneInfo.data_config/0","doc":"The configuration for data generation.\n\n- `:files`: The list of files from the IANA DB download.\n- `:time_zones`: The list of time zones that will be used. The atom `:all`\n  indicates that all time zones from the IANA DB will be used.\n- `:lookahead`: Number of years for which data are precalculated.\n\nSee `Config` page for more information.","ref":"TimeZoneInfo.html#t:data_config/0"},{"type":"type","title":"TimeZoneInfo.gregorian_seconds/0","doc":"Seconds since year 0 in the gregorian calendar.","ref":"TimeZoneInfo.html#t:gregorian_seconds/0"},{"type":"type","title":"TimeZoneInfo.rule/0","doc":"A rule representation.","ref":"TimeZoneInfo.html#t:rule/0"},{"type":"type","title":"TimeZoneInfo.rule_name/0","doc":"The name of a rule set that can be found in the IANA data.","ref":"TimeZoneInfo.html#t:rule_name/0"},{"type":"type","title":"TimeZoneInfo.rules_ref/0","doc":"A reference to a rule set. The reference also contains `utc_offset` and\n`format`,\nThe reference contains `utc_offset` and `format` because these values are needed\nto apply a `rule`.","ref":"TimeZoneInfo.html#t:rules_ref/0"},{"type":"type","title":"TimeZoneInfo.time_standard/0","doc":"The time standards used by IANA.","ref":"TimeZoneInfo.html#t:time_standard/0"},{"type":"type","title":"TimeZoneInfo.time_zone_period/0","doc":"A period where a certain combination of UTC offset, standard offset and zone\nabbreviation is in effect. The `wall_period` contains the start and end of the\ntime zone period in wall time.","ref":"TimeZoneInfo.html#t:time_zone_period/0"},{"type":"type","title":"TimeZoneInfo.time_zones/0","doc":"","ref":"TimeZoneInfo.html#t:time_zones/0"},{"type":"type","title":"TimeZoneInfo.transition/0","doc":"A transition marks a point in time when one or more of the values `utc-offset`,\n`std_offset` or `zone-abbr` change.","ref":"TimeZoneInfo.html#t:transition/0"},{"type":"type","title":"TimeZoneInfo.wall_period/0","doc":"The wall time period represented in a tuple with two naive date times.","ref":"TimeZoneInfo.html#t:wall_period/0"},{"type":"type","title":"TimeZoneInfo.zone_state/0","doc":"The `zone_state` is either a `timezone_period` or a `rules_ref`.","ref":"TimeZoneInfo.html#t:zone_state/0"},{"type":"module","title":"TimeZoneInfo.TimeZoneDatabase","doc":"Implementation of the `Calendar.TimeZoneDatabase` behaviour.","ref":"TimeZoneInfo.TimeZoneDatabase.html"},{"type":"behaviour","title":"TimeZoneInfo.DataPersistence","doc":"A behaviour to persist the data.","ref":"TimeZoneInfo.DataPersistence.html"},{"type":"callback","title":"TimeZoneInfo.DataPersistence.checksum/0","doc":"Returns the checksum for the persisted data.","ref":"TimeZoneInfo.DataPersistence.html#c:checksum/0"},{"type":"callback","title":"TimeZoneInfo.DataPersistence.fetch/0","doc":"Returns the persisted data.","ref":"TimeZoneInfo.DataPersistence.html#c:fetch/0"},{"type":"callback","title":"TimeZoneInfo.DataPersistence.fetch_last_update/0","doc":"Returns the timestamp of the last update in seconds since epoch.","ref":"TimeZoneInfo.DataPersistence.html#c:fetch_last_update/0"},{"type":"callback","title":"TimeZoneInfo.DataPersistence.info/0","doc":"Returns infos about the persisted data.","ref":"TimeZoneInfo.DataPersistence.html#c:info/0"},{"type":"callback","title":"TimeZoneInfo.DataPersistence.put/1","doc":"Persists the given data.","ref":"TimeZoneInfo.DataPersistence.html#c:put/1"},{"type":"callback","title":"TimeZoneInfo.DataPersistence.put_last_update/1","doc":"Sets `time` as last update time stamp. `time` is given in seconds since epoch.","ref":"TimeZoneInfo.DataPersistence.html#c:put_last_update/1"},{"type":"behaviour","title":"TimeZoneInfo.DataStore","doc":"A behaviour to store data and serve them later on.","ref":"TimeZoneInfo.DataStore.html"},{"type":"callback","title":"TimeZoneInfo.DataStore.delete!/0","doc":"Deletes all data in the data store.","ref":"TimeZoneInfo.DataStore.html#c:delete!/0"},{"type":"callback","title":"TimeZoneInfo.DataStore.empty?/0","doc":"Returns true if the `DataSore` is empty.","ref":"TimeZoneInfo.DataStore.html#c:empty?/0"},{"type":"callback","title":"TimeZoneInfo.DataStore.fetch_rules/1","doc":"Returns `rules` for a given `rule_name`.","ref":"TimeZoneInfo.DataStore.html#c:fetch_rules/1"},{"type":"callback","title":"TimeZoneInfo.DataStore.fetch_transitions/1","doc":"Returns the `transitions` for a given `time_zone`.","ref":"TimeZoneInfo.DataStore.html#c:fetch_transitions/1"},{"type":"callback","title":"TimeZoneInfo.DataStore.get_time_zones/1","doc":"Returns the list of all available time zones with or without links. The option\n`:links` can be used to customize the list.\n\nValues for `:links`:\n- `:ignore` just the time zone names will be returned\n- `:only` just the link name will be returned\n- `:include` the time zone and link names will be returned\n\nThe list will be sorted.","ref":"TimeZoneInfo.DataStore.html#c:get_time_zones/1"},{"type":"callback","title":"TimeZoneInfo.DataStore.info/0","doc":"Returns infos about the data store.","ref":"TimeZoneInfo.DataStore.html#c:info/0"},{"type":"callback","title":"TimeZoneInfo.DataStore.put/1","doc":"Puts the given `data` into the store.","ref":"TimeZoneInfo.DataStore.html#c:put/1"},{"type":"callback","title":"TimeZoneInfo.DataStore.version/0","doc":"Returns the version of the IANA database from which the data was generated.","ref":"TimeZoneInfo.DataStore.html#c:version/0"},{"type":"behaviour","title":"TimeZoneInfo.Downloader","doc":"The behaviour for downloaders.","ref":"TimeZoneInfo.Downloader.html"},{"type":"callback","title":"TimeZoneInfo.Downloader.download/2","doc":"","ref":"TimeZoneInfo.Downloader.html#c:download/2"},{"type":"type","title":"TimeZoneInfo.Downloader.download/0","doc":"","ref":"TimeZoneInfo.Downloader.html#t:download/0"},{"type":"type","title":"TimeZoneInfo.Downloader.headers/0","doc":"HTTP headers.","ref":"TimeZoneInfo.Downloader.html#t:headers/0"},{"type":"type","title":"TimeZoneInfo.Downloader.mode/0","doc":"The `mode` to download the data.\n\nPossible modes:\n- `:iana` downloads the data as a zipped tar archive in IANA format.\n- `:etf` downloads the data as a compressed file in the `TimeZoneInfo`\n  [External Term Format](http://erlang.org/doc/apps/erts/erl_ext_dist.html).\n- `:ws` downloads the data from a web service.  In this mode, the\n  configuration is sent to the server. The returned data is transformed\n  according to the config on the server and comes in the same format as in the\n  mode `:etf`.","ref":"TimeZoneInfo.Downloader.html#t:mode/0"},{"type":"type","title":"TimeZoneInfo.Downloader.opts/0","doc":"","ref":"TimeZoneInfo.Downloader.html#t:opts/0"},{"type":"type","title":"TimeZoneInfo.Downloader.status_code/0","doc":"HTTP status code","ref":"TimeZoneInfo.Downloader.html#t:status_code/0"},{"type":"behaviour","title":"TimeZoneInfo.Listener","doc":"A `behaviour` for `TimeZoneInfo` listeners.","ref":"TimeZoneInfo.Listener.html"},{"type":"callback","title":"TimeZoneInfo.Listener.on_update/1","doc":"A callback to listen on the update process.\n\nPossible events:\n- `:initial` initializing data.\n- `:check` checking whether an update is necessary.\n- `:force` an update is forced.\n- `:download` downloads data.\n- `:update` updating data.\n- `:disabled` updating data is disabled.\n- `{:error, reason}`","ref":"TimeZoneInfo.Listener.html#c:on_update/1"},{"type":"module","title":"TimeZoneInfo.DataPersistence.FileSystem","doc":"An implementation for the behaviour `TimeZoneInfo.DataPersistence` to persist\ndata in the file system.","ref":"TimeZoneInfo.DataPersistence.FileSystem.html"},{"type":"module","title":"TimeZoneInfo.DataPersistence.Priv","doc":"An implementation for the behaviour `TimeZoneInfo.DataPersistence` to persist\ndata in the `priv` dir.","ref":"TimeZoneInfo.DataPersistence.Priv.html"},{"type":"module","title":"TimeZoneInfo.Downloader.Mint","doc":"An implementation of the `TimeZoneInfo.Downloader` behaviour using `Mint`.","ref":"TimeZoneInfo.Downloader.Mint.html"},{"type":"module","title":"TimeZoneInfo.Listener.ErrorLogger","doc":"A listener to log `TimeZoneInfo` errors.\n\nThis is the default implementation of the `TimeZoneInfo.Listener`.","ref":"TimeZoneInfo.Listener.ErrorLogger.html"},{"type":"module","title":"TimeZoneInfo.Listener.Logger","doc":"A listener to log `TimeZoneInfo` events.","ref":"TimeZoneInfo.Listener.Logger.html"},{"type":"module","title":"TimeZoneInfo.IanaParser","doc":"The IANA-Parser builds the data structure for `TimeZoneInfo`.\n\nThe format of the IANA data explains the article [How to Read the tz Database\nSource Files](https://data.iana.org/time-zones/tz-how-to.html)","ref":"TimeZoneInfo.IanaParser.html"},{"type":"function","title":"TimeZoneInfo.IanaParser.parse/1","doc":"Builds the data structure `IanaParser.output` from the `iana_data`.","ref":"TimeZoneInfo.IanaParser.html#parse/1"},{"type":"function","title":"TimeZoneInfo.IanaParser.parse/2","doc":"Builds the data structure `IanaParser.output` from the IANA data in `files`\nunder `path`.","ref":"TimeZoneInfo.IanaParser.html#parse/2"},{"type":"type","title":"TimeZoneInfo.IanaParser.data/0","doc":"The raw IANA data.","ref":"TimeZoneInfo.IanaParser.html#t:data/0"},{"type":"type","title":"TimeZoneInfo.IanaParser.day/0","doc":"","ref":"TimeZoneInfo.IanaParser.html#t:day/0"},{"type":"type","title":"TimeZoneInfo.IanaParser.op/0","doc":"","ref":"TimeZoneInfo.IanaParser.html#t:op/0"},{"type":"type","title":"TimeZoneInfo.IanaParser.output/0","doc":"The parsed data.","ref":"TimeZoneInfo.IanaParser.html#t:output/0"},{"type":"type","title":"TimeZoneInfo.IanaParser.rule/0","doc":"","ref":"TimeZoneInfo.IanaParser.html#t:rule/0"},{"type":"type","title":"TimeZoneInfo.IanaParser.time/0","doc":"","ref":"TimeZoneInfo.IanaParser.html#t:time/0"},{"type":"type","title":"TimeZoneInfo.IanaParser.until/0","doc":"","ref":"TimeZoneInfo.IanaParser.html#t:until/0"},{"type":"type","title":"TimeZoneInfo.IanaParser.zone_state/0","doc":"","ref":"TimeZoneInfo.IanaParser.html#t:zone_state/0"},{"type":"module","title":"TimeZoneInfo.Transformer","doc":"The `Transformer` transfers the parsed IANA data into the required format for\n`TimeZoneInfo`.","ref":"TimeZoneInfo.Transformer.html"},{"type":"function","title":"TimeZoneInfo.Transformer.transform/3","doc":"Transforms the `iana_data` into a map of type `TimeZoneInfo.data()`.","ref":"TimeZoneInfo.Transformer.html#transform/3"},{"type":"function","title":"TimeZoneInfo.Transformer.used_rules/1","doc":"Searching for rules used by time zones.\n\nA rule can just emit on the head of a transition list.","ref":"TimeZoneInfo.Transformer.html#used_rules/1"},{"type":"type","title":"TimeZoneInfo.Transformer.version/0","doc":"","ref":"TimeZoneInfo.Transformer.html#t:version/0"},{"type":"module","title":"TimeZoneInfo.Transformer.Abbr","doc":"This module provides some functions to create time zone abbreviations.","ref":"TimeZoneInfo.Transformer.Abbr.html"},{"type":"function","title":"TimeZoneInfo.Transformer.Abbr.create/4","doc":"Creates the zone abbr.","ref":"TimeZoneInfo.Transformer.Abbr.html#create/4"},{"type":"type","title":"TimeZoneInfo.Transformer.Abbr.format/0","doc":"The format of a `zone_abbr`.","ref":"TimeZoneInfo.Transformer.Abbr.html#t:format/0"},{"type":"type","title":"TimeZoneInfo.Transformer.Abbr.letters/0","doc":"The `letters` for the zone abbr format.","ref":"TimeZoneInfo.Transformer.Abbr.html#t:letters/0"},{"type":"module","title":"TimeZoneInfo.Transformer.Rule","doc":"This module handles and transforms the IANA rules.","ref":"TimeZoneInfo.Transformer.Rule.html"},{"type":"function","title":"TimeZoneInfo.Transformer.Rule.max/1","doc":"Returns all rules form the rule set that are for now valid until end of time.","ref":"TimeZoneInfo.Transformer.Rule.html#max/1"},{"type":"function","title":"TimeZoneInfo.Transformer.Rule.max?/1","doc":"Returns `true` if `rule` is valid until end of time or one of the `rules` is valid\nuntil end of time.","ref":"TimeZoneInfo.Transformer.Rule.html#max?/1"},{"type":"function","title":"TimeZoneInfo.Transformer.Rule.to_rule_set/2","doc":"Returns a rule-set for the given `rules`.","ref":"TimeZoneInfo.Transformer.Rule.html#to_rule_set/2"},{"type":"function","title":"TimeZoneInfo.Transformer.Rule.to_rule_sets/2","doc":"Returns a map of rule-set for the given map of `rules`.","ref":"TimeZoneInfo.Transformer.Rule.html#to_rule_sets/2"},{"type":"function","title":"TimeZoneInfo.Transformer.Rule.transform/1","doc":"Transforms a `IanaParser.rule` to a `TimeZoneInfo.rule`. If the function gets\na list then all rules will be transformed.","ref":"TimeZoneInfo.Transformer.Rule.html#transform/1"},{"type":"module","title":"TimeZoneInfo.Transformer.RuleSet","doc":"A rule set is a set of IANA rules with one entry per rule execution.","ref":"TimeZoneInfo.Transformer.RuleSet.html"},{"type":"function","title":"TimeZoneInfo.Transformer.RuleSet.transitions/3","doc":"Generates transitions for the given `rule_set`.","ref":"TimeZoneInfo.Transformer.RuleSet.html#transitions/3"},{"type":"function","title":"TimeZoneInfo.Transformer.RuleSet.transitions/7","doc":"Generates the transitions for the given `zone_state`.","ref":"TimeZoneInfo.Transformer.RuleSet.html#transitions/7"},{"type":"type","title":"TimeZoneInfo.Transformer.RuleSet.rule/0","doc":"","ref":"TimeZoneInfo.Transformer.RuleSet.html#t:rule/0"},{"type":"type","title":"TimeZoneInfo.Transformer.RuleSet.t/0","doc":"","ref":"TimeZoneInfo.Transformer.RuleSet.html#t:t/0"},{"type":"module","title":"TimeZoneInfo.Transformer.ZoneState","doc":"The transformer for time-zones.","ref":"TimeZoneInfo.Transformer.ZoneState.html"},{"type":"function","title":"TimeZoneInfo.Transformer.ZoneState.add_wall_period/1","doc":"","ref":"TimeZoneInfo.Transformer.ZoneState.html#add_wall_period/1"},{"type":"function","title":"TimeZoneInfo.Transformer.ZoneState.transform/3","doc":"Transforms the `IanaPraser.zone` data in a list of `TimeZoneInfo.transition`.","ref":"TimeZoneInfo.Transformer.ZoneState.html#transform/3"},{"type":"function","title":"TimeZoneInfo.Transformer.ZoneState.until/2","doc":"Returns the until datetime for the given `zone_state` and `std_offset`.","ref":"TimeZoneInfo.Transformer.ZoneState.html#until/2"},{"type":"extras","title":"TimeZoneInfo","doc":"# TimeZoneInfo\n[![Hex.pm: version](https://img.shields.io/hexpm/v/time_zone_info.svg?style=flat-square)](https://hex.pm/packages/time_zone_info)\n[![GitHub: CI status](https://img.shields.io/github/actions/workflow/status/hrzndhrn/time_zone_info/ci.yml?branch=main&style=flat-square)](https://github.com/hrzndhrn/time_zone_info/actions)\n[![Coveralls: coverage](https://img.shields.io/coveralls/github/hrzndhrn/time_zone_info?style=flat-square)](https://coveralls.io/github/hrzndhrn/time_zone_info)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg?style=flat-square)](https://github.com/hrzndhrn/time_zone_info/blob/main/LICENSE.md)\n\nTime zone support for Elixir by using the\n[IANA Time Zone Database](https://www.iana.org/time-zones).","ref":"readme.html"},{"type":"extras","title":"Installation - TimeZoneInfo","doc":"The package can be installed by adding `time_zone_info` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:time_zone_info, \"~> 0.7\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - TimeZoneInfo","doc":"After installation, `TimeZoneInfo` can be used as follows.\n```elixir\niex> TimeZoneInfo.iana_version\n\"2024b\"\niex> TimeZoneInfo.time_zones() |> Enum.take(3)\n[\"Africa/Abidjan\", \"Africa/Accra\", \"Africa/Addis_Ababa\"]\niex> TimeZoneInfo.TimeZoneDatabase.time_zone_periods_from_wall_datetime(~N[2021-09-23 09:56:00], \"Europe/Berlin\")\n{:ok,\n %{\n   std_offset: 3600,\n   utc_offset: 3600,\n   wall_period: {~N[2021-03-28 03:00:00], ~N[2021-10-31 03:00:00]},\n   zone_abbr: \"CEST\"\n }}\n```\n\nIn combination with `DateTime` and `Calendar`:\n```elixir\niex> {:ok, berlin} = DateTime.from_naive(\n...>   ~N[2020-03-29 01:30:00],\n...>   \"Europe/Berlin\",\n...>    TimeZoneInfo.TimeZoneDatabase)\n{:ok, #DateTime<2020-03-29 01:30:00+01:00 CET Europe/Berlin>}\niex> Calendar.put_time_zone_database(TimeZoneInfo.TimeZoneDatabase)\n:ok\niex> DateTime.shift_zone(berlin, \"America/New_York\")\n{:ok, #DateTime<2020-03-28 20:30:00-04:00 EDT America/New_York>}\n```\n\nInstead of the line\n`Calendar.put_time_zone_database(TimeZoneInfo.TimeZoneDatabase)` you can also\nspecify the following entry in the configuration.\n```elixir\nconfig :elixir, :time_zone_database, TimeZoneInfo.TimeZoneDatabase\n```","ref":"readme.html#usage"},{"type":"extras","title":"Config - TimeZoneInfo","doc":"`TimeZoneInfo` has several configuration options:\n+ Enable automated updates from the IANA tzdb\n+ Setup for how many years rules will be precalculated\n+ Selection of supported time zones\n\nFor more information how to configure `TimeZoneInfo` see\n[Config](https://hexdocs.pm/time_zone_info/config.html).","ref":"readme.html#config"},{"type":"extras","title":"Default Time Zone Data - TimeZoneInfo","doc":"The default configuration of `TimeZoneInfo` is `update: :disabled`. In this\ncase, the IANA database in version `2024b` with a `lookahead` of 15 years is in\nuse.\n\nIf a time zone has continuation rules, the periods after the lookahead are\ncalculating by these rules. Note, these calculations are much more expensive as\nthe determination of periods inside the prepared time span.","ref":"readme.html#default-time-zone-data"},{"type":"extras","title":"Benchmarks - TimeZoneInfo","doc":"The benchmarks can be executed with `mix bench`.\n\nBenchmarks:\n+ This [benchmark](https://github.com/hrzndhrn/time_zone_info/blob/main/bench/time_zone_database_bench.md)\n  compares `TimeZoneInfo` with `Tzdata`, `Tz` and `Zoneinfo`.\n\n+ This [benchmark](https://github.com/hrzndhrn/time_zone_info/blob/main/bench/stores_bench.md)\n  compares the different `TimeZoneInfo.DataStore`s.\n\n+ This [benchmark](https://github.com/hrzndhrn/time_zone_info/blob/main/bench/transform_bench.md)\n  measures the speed of transforming the raw IANA data to the required format at\n  runtime.","ref":"readme.html#benchmarks"},{"type":"extras","title":"Differences to Tzdata and Tz - TimeZoneInfo","doc":"There are some differences to `Tzdata` and `Tz`. The list shows differences to\n`Tzdata` and/or `Tz`.\n\n- Use of `:persitent_term` with an optional use of `:ets`.\n- Persisting data in\n  [External Term Format](http://erlang.org/doc/apps/erts/erl_ext_dist.html)\n- The data persisting is customizable by the behaviour\n  `TimeZoneInfo.DataPersistence`.\n- Optional download of time zone data in `TimeZoneInfo` format.\n- The download is customizable by the behaviour `TimeZoneInfo.Downloader`.\n- Filter time zones per config.\n- Optional listener that will be called on updates.\n- `TimeZoneInfo` calculates periods in the far future by continuation rules.\n  Except for time zones that have daylight saving times for Ramadan.","ref":"readme.html#differences-to-tzdata-and-tz"},{"type":"extras","title":"References - TimeZoneInfo","doc":"The home of the IANA Time Zone Database: https://www.iana.org/time-zones\n\nLinks:\n- [Time zone](https://en.wikipedia.org/wiki/Time_zone) - Wikipedia\n- [**time**and**date**.com](https://www.timeanddate.com/)\n- [WorldTimeServer.com](https://www.worldtimeserver.com/)\n\nOther Elixir implementations:\n- [tzdata](https://github.com/lau/tzdata) - Tzdata is a parser and library for\n  the tz database.\n- [tz](https://github.com/mathieuprog/tz) - Time zone support for Elixir\n- [zoneinfo](https://github.com/smartrent/zoneinfo) - Elixir time zone support\n  for your OS-supplied zoneinfo files\n\nOther implementations:\n- [DateTime::TimeZone](https://github.com/houseabsolute/DateTime-TimeZone) - Perl\n  - `TimeZoneInfo` use this module as a checker in the tests.\n- [NodaTime](https://nodatime.org/) - A better date and time API for .NET\n  - `TimeZonInfo` use some data from this\n    [site](https://nodatime.org/tzvalidate/generate?version=2019c) in the tests.","ref":"readme.html#references"},{"type":"extras","title":"Config","doc":"# Config\n\nAdd the following line to use `TimeZoneInfo` per default in the project.\n```\nconfig :elixir, :time_zone_database, TimeZoneInfo.TimeZoneDatabase\n```","ref":"config.html"},{"type":"extras","title":"Enable automated updates - Config","doc":"The automated update uses the default `Downloader`, and this one uses\n[`Mint`](https://github.com/elixir-mint/mint). Therefore the following\ndependencies are needed in `mix.exs`.\n```\ndefp deps do\n  [\n    ...\n    {:castore, \"~> 0.1.0\"},\n    {:mint, \"~> 1.0\"},\n    ...\n  ]\nend\n```\nThe config has to be extended with:\n```\nconfig :time_zone_info, update: :daily\n```","ref":"config.html#enable-automated-updates"},{"type":"extras","title":"Custom downloader - Config","doc":"It is also possible to use your own downloader. This requires an implementation\nof the behaviour `TimeZoneInfo.Downloader`. The custom downloader has to be\nspecified in the config.\n```\nconfig :time_zone_info, [\n  update: :daily,\n  downloader: [\n    module: MyApp.TimeZonInfo.Downloader,\n    uri: \"https://data.iana.org/time-zones/tzdata-latest.tar.gz\",\n    mode: :iana,\n    headers: [\n      {\"Content-Type\", \"application/tar+gzip\"},\n      {\"User-Agent\", \"Elixir.TimeZoneInfo.Mint\"}\n    ]\n  ],\n]\n```\n\nThe option `update` specifies the update interval. Possible values are `:daily`\nand `:disabled` to disable the automated update.\n\nThe keys `uri` and `headers` containing to download the data.\n\nThe key `mode` can contain `:iana`, `:etf`, or `:ws` and indicates whether they\ndata are delivered in IANA format (.tar.gz) or in zipped ETF\n([External Term Format](http://erlang.org/doc/apps/erts/erl_ext_dist.html)).\n\nIn `:ws` mode, the request for the data contains query parameters. The parameters\nare containing the configuration:\n- `files[]`: A list of IANA files which are used to generate the\n  `TimeZoneInfo.data`.\n- `time_zones[]`: A list of time zones. These parameters do not apply if no\n  time zones are specified.\n- `lookahead`\n\nThe response format in `:ws` mode is the same as in `:etf` mode.","ref":"config.html#custom-downloader"},{"type":"extras","title":"Time zone manipulation - Config","doc":"`TimeZoneInfo` provides some configuration options to select a subset form the\navailable time zones and the size of the generated periods table.\n\n```\nconfig :time_zone_info,\n  ...\n  files: ~w(europe asia),\n  time_zones: ~w(Europe Asia/Istanbul),\n  lookahead: 5\n```\n\n`files:`\\\nDefault: `[\"africa\", \"antarctica\", \"asia\", \"australasia\", \"backward\",\n\"etcetera\", \"europe\", \"northamerica\", \"southamerica\")`\\\nThis option specifies which files are parsed from the IANA data. The files\n`europe`, `asia`, etc are self-explanatory. The file `ecetera` contains time\nzones like `Etc/UTC`, `Etc/Zulu`, `Etc/GMT+1`, etc. The `backward` file contains\nobsolete time zones. If you do not need the obsolete time zones, configure a\nlist without the `backward` file.\n**Note:** The configuration `:files` takes no effect if `update: :disabled` is\nset.\n\n`time_zones:`\\\nDefault: `:all`\\\nWith `time_zones:` you can determine which time zones should be used. This\nconfiguration expected a list of time zone names and/or areas like\n`[\"Asia\", \"Europe/Berlin\"]`. In this example all time zones in the area Asia and\nthe time zone \"Europe/Berlin\" are available.\nIf a time zone link matches the `time_zones` configuration, the linked time zone\nwill be also be available. For example, if you set `time_zones: [\"Europe/Jersey\"]`\nthen the time zone `Europe/London` is also available because `Europe/Jersey`\nlinks this time zone.\n\n`lookahead:`\\\nDefault: `5`\\\nThe `lookahead` specifies for how many years from now the periods will be\ncalculated.\\\n**Note:** They configuration `:lookahead` takes no effect if `update: :disabled`\nis set.","ref":"config.html#time-zone-manipulation"},{"type":"extras","title":"Data persistence - Config","doc":"`TimeZoneInfo` has two implementations of the behaviour\n`TimeZoneInfo.DataPersistence` to persist data.\n\n`TimeZoneInfo.DataPersistence.Priv` is used in the default configuration.\n```\nconfig :time_zone_info,\n  ...\n  data_persistence: TimeZoneInfo.DataPersistence.Priv,\n  priv: [path: \"data.etf\"]\n```\nThis module is intended for simple configurations. The specified `data.etf` is\npart of the `TimeZoneInfo` package and contains the transformed data from the\nactual IANA time zone DB.\n\n`TimeZoneInfo.DataPersistence.FileSystem` stores the data in a file to be\nspecified.\n```\nconfig :time_zone_info,\n  ...\n  data_persistence: TimeZoneInfo.DataPersistence.FileSystem,\n  file_system: [path: \"data/tzi.etf\"]\n```","ref":"config.html#data-persistence"},{"type":"extras","title":"The data store - Config","doc":"`TimeZoneInfo` provides two methods to store data at runtime.\nThe data can be stored either with `:persistent_term` or with `:ets`. The option\n`data_store` holds this configuration. With `data_store: :detect` (default) the\nmethod with `:persistent_term` will be used if `:persitent_term` is available\n(OTP >= 21.2). To set a method explicitly use\n`data_store: TimeZoneInfo.DataStore.PersistentTerm` or\n`data_store: TimeZoneInfo.DataStore.ErlangTermStorage`.","ref":"config.html#the-data-store"},{"type":"extras","title":"No runtime config, no delete - Config","doc":"It is not recomented to update the configuration at runtime. Becaus the data\nin runtime will just be updated but never deleted. That means if you change\n`time_zones: :all` to `time_zones: [\"Europe\"]` then **all** time zones are\navailable after an update.\n\nThis is not a problem for the automated update. Because all period tables will\nbe updated.","ref":"config.html#no-runtime-config-no-delete"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.7.5 - 2024/09/08 - Changelog","doc":"- Fix warning by conditionally compiling `TimeZoneInfo.Downloader.Mint`.","ref":"changelog.html#0-7-5-2024-09-08"},{"type":"extras","title":"0.7.4 - 2024/09/08 - Changelog","doc":"- Update `priv/data.etf` with IANA tzdata version 2024b.\n- Update the parser to accept months and days also  as a full name.\n- Add support for zome abbr format `%z`.","ref":"changelog.html#0-7-4-2024-09-08"},{"type":"extras","title":"0.7.3 - 2024/05/09 - Changelog","doc":"- Update `priv/data.etf` with IANA tzdata version 2024a.","ref":"changelog.html#0-7-3-2024-05-09"},{"type":"extras","title":"0.7.2 - 2024/01/12 - Changelog","doc":"- Update `priv/data.etf` with IANA tzdata version 2023d.","ref":"changelog.html#0-7-2-2024-01-12"},{"type":"extras","title":"0.7.1 - 2023/12/24 - Changelog","doc":"- Bump required Elixir version to 1.12.","ref":"changelog.html#0-7-1-2023-12-24"},{"type":"extras","title":"0.7.0 - 2023/11/03 - Changelog","doc":"- Bump required Elixir version to 1.11.\n- Use `Calenadar.ISO.day_of_week/4`.\n- Refactor `TimeZoneInfo.DataStore.PersistentTerm`","ref":"changelog.html#0-7-0-2023-11-03"},{"type":"extras","title":"0.6.5 - 2023/05/10 - Changelog","doc":"- Update `priv/data.etf` with IANA tzdata version 2023c.","ref":"changelog.html#0-6-5-2023-05-10"},{"type":"extras","title":"0.6.4 - 2022/11/09 - Changelog","doc":"- Fix bug for negative dates.","ref":"changelog.html#0-6-4-2022-11-09"},{"type":"extras","title":"0.6.3 - 2022/10/31 - Changelog","doc":"- Update `priv/data.etf` with IANA tzdata version 2022f.","ref":"changelog.html#0-6-3-2022-10-31"},{"type":"extras","title":"0.6.2 - 2022/07/24 - Changelog","doc":"- Update `priv/data.etf` with IANA tzdata version 2022a.\n- Update `TimeZoneInfo.DataPersistence.Priv`.","ref":"changelog.html#0-6-2-2022-07-24"},{"type":"extras","title":"0.6.1 - 2022/02/05 - Changelog","doc":"- Update `priv/data.etf` with IANA tzdata version 2021e.\n- Add minor refactorings.","ref":"changelog.html#0-6-1-2022-02-05"},{"type":"extras","title":"0.6.0 - 2021/09/25 - Changelog","doc":"- Update required Elixir version to `~> 1.10`\n- Replace :crypto.hash/2 by :erlang.phash/1.\n- Update `priv/data.etf` with IANA tzdata version 2021b.","ref":"changelog.html#0-6-0-2021-09-25"},{"type":"extras","title":"0.5.3 - 2021/03/13 - Changelog","doc":"- Update `priv/data.etf` with IANA tzdata version 2021a.","ref":"changelog.html#0-5-3-2021-03-13"},{"type":"extras","title":"0.5.3 - 2021/01/13 - Changelog","doc":"- Update `priv/data.etf` with IANA tzdata version 2020f.","ref":"changelog.html#0-5-3-2021-01-13"},{"type":"extras","title":"0.5.2 - 2020/10/26 - Changelog","doc":"- Update `priv/data.etf` with IANA tzdata version 2020d.","ref":"changelog.html#0-5-2-2020-10-26"},{"type":"extras","title":"0.5.1 - 2020/07/08 - Changelog","doc":"- Support different calendars.","ref":"changelog.html#0-5-1-2020-07-08"},{"type":"extras","title":"0.5.0 - 2020/06/08 - Changelog","doc":"- Increasing speed of `TimeZoneDatabase.time_zone_periods_from_wall_datetime/2`.\n- Adding `wall_time` to `time_zone_period`.\n- Refactoring `updater` to fix some unexpected behaviours when changing configs.\n- Updating docs structure.\n- Adding `backward` to the default `files`.\n- Refactoring `time_zones` configuration behaviour.\n  See [Time zone maniputlation](https://hexdocs.pm/time_zone_info/config.html#time-zone-manipulation).","ref":"changelog.html#0-5-0-2020-06-08"},{"type":"extras","title":"0.4.0 - 2020/04/25 - Changelog","doc":"- Updating `priv/data.etf` with IANA tzdata version 2020a.\n- The Etc/UTC time-zone is always supported, no matter how the configuration is specified.\n- Adding `TimeZoneInfo.DataPersistence.FileSystem`.\n- Changing configuration option `format` to `mode`.\n- Adding mode `:ws`. In this mode the `Downloader` will call a web service to\n  fetch data.\n- Adding `TimeZoneInfo.data/2`, this function generates `TimeZoneInfo.data` and\n  is intended for use in a time-zone-info-server.\n- Adding examples `TimeZoneInfoServer` and `Clock`.\n- Making some modules private. According to [Hiding Internal Modules and Functions](https://hexdocs.pm/elixir/master/writing-documentation.html#hiding-internal-modules-and-functions).","ref":"changelog.html#0-4-0-2020-04-25"},{"type":"extras","title":"0.3.0 - 2020/04/15 - Changelog","doc":"- Using `plug_cowboy` instead of `cowboy` in tests.\n- Adding HTTP status code to the downloader.\n- Updating default `lookahead` to 15 years.\n- Refactoring date time handling.\n- Adding `TimeZoneInfo.info/0`.\n- Adding optional `info/0` callback to the `DataStore` behaviour.\n- Adding optional `info/0` callback to the `DataPersistence` behaviour.\n- Adding `TimeZoneInfo.Listener.ErrorLogger`.","ref":"changelog.html#0-3-0-2020-04-15"},{"type":"extras","title":"0.2.0 - 2020/04/08 - Changelog","doc":"- Reimplementation of the `TimeZoneInfo.Transformer` to fix a bunch of bugs.\n- Update parser to handle CRs.","ref":"changelog.html#0-2-0-2020-04-08"},{"type":"extras","title":"0.1.1 - 2020/03/28 - Changelog","doc":"Fix github link in package.","ref":"changelog.html#0-1-1-2020-03-28"},{"type":"extras","title":"0.1.0 - 2020/03/28 - Changelog","doc":"Initial release.","ref":"changelog.html#0-1-0-2020-03-28"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}